{ config, lib, pkgs, ... }:

let
  cfg = config.r6d.config-generator;
  computers = config.r6d.computers;
  profiles = config.r6d.profiles;
  mkIf = lib.mkIf;
in

{
  imports = [                   # applications :
    # commandées par config-generator
    ./activation-manuelle/xmonad/xmonad.nix      # gestionnaire de fenêtres xmonad
  ];

  # Paquets
  environment.systemPackages = with pkgs; mkIf profiles.isDesktop [
    # Environement de bureau
    arandr          # interface graphique pour xrandr
    wmname          # pour définir le nom du gestionnaire de fenêtre (utile pour java)
    kde4.ksnapshot# capture d'écran
    xorg.xbacklight # pour gérer la luminosité de l'écran
    xorg.xev        # pour repérer les codes + noms standard des actions clavier/souris
    xorg.xkill      # pour 'tuer une application'

    ## Gestionnaire de fenêtre & Thème
    gnome.gnome_icon_theme  # thème d'icone - semble fonctionner avec spaceFM

    ## Manipulation de fichier
    pcmanfm         # gestionnaire de fichiers graphique
    spaceFM         # gestionnaire de fichiers graphique
    vifm            # gestionnaire de fichiers basé sur VIM (console)

    ## Terminal
    sakura          # terminal

    # A trier
    cowsay
    fgallery        # générateur de gallerie statique http://www.thregr.org/~wavexx/software/fgallery/
    samba
    taskwarrior     # gestionnaire de tâches en console
    udevil          # pour le montage des media amovibles
    xclip           # manipulation du clipboard X depuis la console
  ];

  # Polices supplémentaires
  fonts.fonts = with pkgs; mkIf profiles.isDesktop [
    fira            # police créée pour Firefox
    fira-code       # idem fira-mono + ligatures pour la programmation
    fira-mono       # dérivée de fira en monospace
    hack-font       # police monospace créée explicitement pour coder
  ];

  nixpkgs.config.packageOverrides = pkgs: {
    clawsMail = pkgs.clawsMail.override { enablePluginFancy = true; };
    mumble = pkgs.mumble.override { pulseSupport = true; };
  };

  security.setuidPrograms = [ "udevil" ];
}
